/**
 * @packageDocumentation
 * @module AccountUIContext
 */
import { ActionType } from '../../types/general';
/**
 * Named dispatch actions for account-related global state changes (i.e. login, forgot password, set password, verify reset code).
 */
export declare const AccountActions: {
    loginStarted: (email: string, transitId: number | null) => {
        readonly type: "Authentication/Login/Started";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
        };
    };
    loginSucceeded: (email: string, transitId: number | null) => {
        readonly type: "Authentication/Login/Succeeded";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
        };
    };
    loginFailed: (email: string, transitId: number | null, errorMessage: string) => {
        readonly type: "Authentication/Login/Failed";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
            readonly errorMessage: string;
        };
    };
    resetLogin: () => {
        readonly type: "Authentication/Login/Reset";
    };
    logout: () => {
        readonly type: "Authentication/Logout/Reset";
    };
    resetPasswordReset: () => {
        readonly type: "Authentication/ResetPassword/Reset";
    };
    resetPasswordStarted: (email: string, transitId: number | null) => {
        readonly type: "Authentication/ResetPassword/Started";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
        };
    };
    resetPasswordSucceeded: (email: string, transitId: number | null) => {
        readonly type: "Authentication/ResetPassword/Succeeded";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
        };
    };
    resetPasswordFailed: (email: string, transitId: number | null, errorMessage: string) => {
        readonly type: "Authentication/ResetPassword/Failed";
        readonly payload: {
            readonly email: string;
            readonly transitId: number;
            readonly errorMessage: string;
        };
    };
    verifyResetCodeReset: () => {
        readonly type: "Authentication/VerifyResetCode/Reset";
    };
    verifyResetCodeStarted: (transitId: number | null) => {
        readonly type: "Authentication/VerifyResetCode/Started";
        readonly payload: {
            readonly transitId: number;
        };
    };
    verifyResetCodeSucceeded: (transitId: number | null) => {
        readonly type: "Authentication/VerifyResetCode/Succeeded";
        readonly payload: {
            readonly transitId: number;
        };
    };
    verifyResetCodeFailed: (transitId: number | null, errorMessage: string) => {
        readonly type: "Authentication/VerifyResetCode/Failed";
        readonly payload: {
            readonly transitId: number;
            readonly errorMessage: string;
        };
    };
    setPasswordReset: () => {
        readonly type: "Authentication/SetPassword/Reset";
    };
    setPasswordStarted: (transitId: number | null) => {
        readonly type: "Authentication/SetPassword/Started";
        readonly payload: {
            readonly transitId: number;
        };
    };
    setPasswordSucceeded: (transitId: number | null) => {
        readonly type: "Authentication/SetPassword/Succeeded";
        readonly payload: {
            readonly transitId: number;
        };
    };
    setPasswordFailed: (transitId: number | null, errorMessage: string) => {
        readonly type: "Authentication/SetPassword/Failed";
        readonly payload: {
            readonly transitId: number;
            readonly errorMessage: string;
        };
    };
};
export type AccountActions = ActionType<typeof AccountActions>;
