"use strict";
/**
 * @packageDocumentation
 * @module AccountUIContext
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountActions = void 0;
/**
 * Named dispatch actions for account-related global state changes (i.e. login, forgot password, set password, verify reset code).
 */
exports.AccountActions = {
    // Login
    loginStarted: function (email, transitId) {
        return ({
            type: 'Authentication/Login/Started',
            payload: { email: email, transitId: transitId },
        });
    },
    loginSucceeded: function (email, transitId) {
        return ({
            type: 'Authentication/Login/Succeeded',
            payload: { email: email, transitId: transitId },
        });
    },
    loginFailed: function (email, transitId, errorMessage) {
        return ({
            type: 'Authentication/Login/Failed',
            payload: { email: email, transitId: transitId, errorMessage: errorMessage },
        });
    },
    resetLogin: function () {
        return ({
            type: 'Authentication/Login/Reset',
        });
    },
    // Logout
    logout: function () {
        return ({
            type: 'Authentication/Logout/Reset',
        });
    },
    // Reset password ("forgot password")
    resetPasswordReset: function () {
        return ({
            type: 'Authentication/ResetPassword/Reset',
        });
    },
    resetPasswordStarted: function (email, transitId) {
        return ({
            type: 'Authentication/ResetPassword/Started',
            payload: { email: email, transitId: transitId },
        });
    },
    resetPasswordSucceeded: function (email, transitId) {
        return ({
            type: 'Authentication/ResetPassword/Succeeded',
            payload: { email: email, transitId: transitId },
        });
    },
    resetPasswordFailed: function (email, transitId, errorMessage) {
        return ({
            type: 'Authentication/ResetPassword/Failed',
            payload: { email: email, transitId: transitId, errorMessage: errorMessage },
        });
    },
    // Verify code for reset password (code from "forgot password" email)
    verifyResetCodeReset: function () {
        return ({
            type: 'Authentication/VerifyResetCode/Reset',
        });
    },
    verifyResetCodeStarted: function (transitId) {
        return ({
            type: 'Authentication/VerifyResetCode/Started',
            payload: { transitId: transitId },
        });
    },
    verifyResetCodeSucceeded: function (transitId) {
        return ({
            type: 'Authentication/VerifyResetCode/Succeeded',
            payload: { transitId: transitId },
        });
    },
    verifyResetCodeFailed: function (transitId, errorMessage) {
        return ({
            type: 'Authentication/VerifyResetCode/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
    // Set password (after a "forgot password" request and verifying a code)
    setPasswordReset: function () {
        return ({
            type: 'Authentication/SetPassword/Reset',
        });
    },
    setPasswordStarted: function (transitId) {
        return ({
            type: 'Authentication/SetPassword/Started',
            payload: { transitId: transitId },
        });
    },
    setPasswordSucceeded: function (transitId) {
        return ({
            type: 'Authentication/SetPassword/Succeeded',
            payload: { transitId: transitId },
        });
    },
    setPasswordFailed: function (transitId, errorMessage) {
        return ({
            type: 'Authentication/SetPassword/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
};
