"use strict";
/**
 * AccountUIStateContext and AccountUIActionContext provide access to global state and actions for account related information (login, forgot password, verify reset password code, etc.).
 *
 * @packageDocumentation
 * @module AccountUIContext
 * @preferred
 * @internal
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountActions = exports.AccountUIActionContext = exports.AccountUIStateContext = exports.useAccountUIActions = exports.useAccountUIState = void 0;
var context_1 = require("./context");
Object.defineProperty(exports, "AccountUIStateContext", { enumerable: true, get: function () { return context_1.StateContext; } });
Object.defineProperty(exports, "AccountUIActionContext", { enumerable: true, get: function () { return context_1.ActionContext; } });
var react_1 = require("react");
__exportStar(require("./types"), exports);
__exportStar(require("./reducer"), exports);
var dispatchActions_1 = require("./dispatchActions");
Object.defineProperty(exports, "AccountActions", { enumerable: true, get: function () { return dispatchActions_1.AccountActions; } });
/**
 * Hook for using the global account state for account-related global [[AccountUIState]] state changes (i.e. login, forgot password, set password, verify reset code).
 *
 * @category Hooks
 */
var useAccountUIState = function () {
    var context = (0, react_1.useContext)(context_1.StateContext);
    if (context === null) {
        throw new Error('useAccountUIState must be used within an AccountUIStateContext');
    }
    return context;
};
exports.useAccountUIState = useAccountUIState;
/**
 * Hook for using the global [[AccountUIActions]] actions (i.e. logIn, forgotPassword, etc.) which change the global [[AccountUIState]].
 *
 * @category Hooks
 */
var useAccountUIActions = function () {
    var context = (0, react_1.useContext)(context_1.ActionContext);
    if (context === null) {
        throw new Error('useAccountUIActions must be used within an AccountUIActionContext');
    }
    return context;
};
exports.useAccountUIActions = useAccountUIActions;
