"use strict";
/**
 * @packageDocumentation
 * @module AccountUIContext
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultAccountUIReducer = void 0;
var state_1 = require("./state");
var TransitState_1 = require("../TransitState");
/**
 * Default reducer for global [[AccountUIState]].
 *
 * @param prevState Previous [[AccountUIState]] to update.
 * @param action State change action, which should be of type [[AccountActions]].
 */
var defaultAccountUIReducer = function (prevState, action) {
    switch (action.type) {
        // Login
        case 'Authentication/Login/Started':
            return __assign(__assign({}, prevState), { login: __assign(__assign({}, (0, TransitState_1.transitStart)()), { email: action.payload.email }), isLogOut: false, email: action.payload.email });
        case 'Authentication/Login/Succeeded':
            return __assign(__assign({}, prevState), { login: __assign(__assign({}, (0, TransitState_1.transitSuccess)()), { email: action.payload.email }), isLogOut: false, email: action.payload.email });
        case 'Authentication/Login/Failed':
            return __assign(__assign({}, prevState), { login: __assign(__assign({}, (0, TransitState_1.transitFailed)(action.payload.errorMessage)), { email: action.payload.email }), isLogOut: false, email: action.payload.email });
        case 'Authentication/Login/Reset':
            return __assign({}, state_1.initialAccountUIState);
        // Logout
        case 'Authentication/Logout/Reset':
            return __assign(__assign({}, state_1.initialAccountUIState), { isLogOut: true });
        // Reset Password ("forgot password" request)
        case 'Authentication/ResetPassword/Reset':
            return __assign(__assign({}, prevState), { forgotPassword: __assign(__assign({}, TransitState_1.initialTransitState), { email: null }) });
        case 'Authentication/ResetPassword/Started':
            return __assign(__assign({}, prevState), { forgotPassword: __assign(__assign({}, (0, TransitState_1.transitStart)(action.payload.transitId)), { email: action.payload.email }) });
        case 'Authentication/ResetPassword/Succeeded':
            if (prevState.forgotPassword.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { forgotPassword: __assign(__assign({}, (0, TransitState_1.transitSuccess)(action.payload.transitId)), { email: action.payload.email }) });
        case 'Authentication/ResetPassword/Failed':
            if (prevState.forgotPassword.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { forgotPassword: __assign(__assign({}, (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId)), { email: action.payload.email }) });
        // Verify code for reset password (code from "forgot password" email)
        case 'Authentication/VerifyResetCode/Reset':
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { verifyResetCodeTransit: TransitState_1.initialTransitState }) });
        case 'Authentication/VerifyResetCode/Started':
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { verifyResetCodeTransit: (0, TransitState_1.transitStart)(action.payload.transitId) }) });
        case 'Authentication/VerifyResetCode/Succeeded':
            if (prevState.setPassword.verifyResetCodeTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { verifyResetCodeTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId) }) });
        case 'Authentication/VerifyResetCode/Failed':
            if (prevState.setPassword.verifyResetCodeTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { verifyResetCodeTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId) }) });
        // Set password (after a "forgot password" request and verifying a code)
        case 'Authentication/SetPassword/Reset':
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { setPasswordTransit: TransitState_1.initialTransitState }) });
        case 'Authentication/SetPassword/Started':
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { setPasswordTransit: (0, TransitState_1.transitStart)(action.payload.transitId) }) });
        case 'Authentication/SetPassword/Succeeded':
            if (prevState.setPassword.setPasswordTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { setPasswordTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId) }) });
        case 'Authentication/SetPassword/Failed':
            if (prevState.setPassword.setPasswordTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { setPassword: __assign(__assign({}, prevState.setPassword), { setPasswordTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId) }) });
        default:
            return prevState;
    }
};
exports.defaultAccountUIReducer = defaultAccountUIReducer;
