"use strict";
/**
 * The AuthUIContextProvider allows for application code to pass in middleware
 * actions that result from the Authentication and Registration user interface.
 * Often the actions will be the local storage and API calls satisfying
 * [[AuthUIActions]] and [[RegistrationUIActions]]. UI configuration properties
 * are also passed in.
 *
 * @packageDocumentation
 * @module AuthUIContextProvider
 * @preferred
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthUIContextProvider = exports.useInjectedUIContext = void 0;
var react_1 = require("react");
var context_1 = require("./context");
var provider_1 = require("./provider");
Object.defineProperty(exports, "AuthUIContextProvider", { enumerable: true, get: function () { return provider_1.AuthUIContextProvider; } });
/**
 * Allows for the module to grab the properties / actions passed in from the applications.
 *
 * @category Hooks
 * @private
 * @internal
 */
var useInjectedUIContext = function () {
    var context = (0, react_1.useContext)(context_1.AuthUIContext);
    if (context === null) {
        throw new Error('useInjectedUIContext must be used within an AuthUIContextProvider');
    }
    return context;
};
exports.useInjectedUIContext = useInjectedUIContext;
