"use strict";
/**
 * @packageDocumentation
 * @module AuthUIContextProvider
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthUIContextProvider = void 0;
var react_1 = __importDefault(require("react"));
var context_1 = require("./context");
var AuthUIContextProvider = function (props) {
    // Extract the needed properties out
    // Context value will not change unless a sub function is changed
    // NOTE: When adding new props to AuthUIContextProviderProps be sure
    // to also add them here so the parameters are copied.
    var memoizedProps = react_1.default.useMemo(function () {
        var propsForContext = {
            authActions: props.authActions,
            registrationActions: props.registrationActions,
            showSelfRegistration: props.showSelfRegistration,
            enableInviteRegistration: props.enableInviteRegistration,
            showContactSupport: props.showContactSupport,
            enableResetPassword: props.enableResetPassword,
            enableCreatePassword: props.enableCreatePassword,
            showRememberMe: props.showRememberMe,
            showCybersecurityBadge: props.showCybersecurityBadge,
            allowDebugMode: props.allowDebugMode,
            projectImage: props.projectImage,
            background: props.background,
            contactEmail: props.contactEmail,
            contactPhone: props.contactPhone,
            contactPhoneLink: props.contactPhoneLink,
            htmlEula: props.htmlEula,
            loginActions: props.loginActions,
            loginFooter: props.loginFooter,
            loginHeader: props.loginHeader,
            loginType: props.loginType,
            loginErrorDisplayConfig: props.loginErrorDisplayConfig,
            passwordRequirements: props.passwordRequirements,
            customAccountDetails: props.customAccountDetails,
            registrationSuccessScreen: props.registrationSuccessScreen,
            accountAlreadyExistsScreen: props.accountAlreadyExistsScreen,
            registrationConfig: props.registrationConfig,
            disablePagerAnimation: props.disablePagerAnimation,
        };
        return propsForContext;
    }, [
        props.accountAlreadyExistsScreen,
        props.allowDebugMode,
        props.authActions,
        props.background,
        props.contactEmail,
        props.contactPhone,
        props.contactPhoneLink,
        props.customAccountDetails,
        props.disablePagerAnimation,
        props.registrationSuccessScreen,
        props.enableInviteRegistration,
        props.enableResetPassword,
        props.enableCreatePassword,
        props.htmlEula,
        props.loginActions,
        props.loginFooter,
        props.loginHeader,
        props.loginType,
        props.loginErrorDisplayConfig,
        props.passwordRequirements,
        props.projectImage,
        props.registrationActions,
        props.showContactSupport,
        props.showRememberMe,
        props.showCybersecurityBadge,
        props.showSelfRegistration,
        props.registrationConfig,
    ]);
    return react_1.default.createElement(context_1.AuthUIContext.Provider, { value: memoizedProps }, props.children);
};
exports.AuthUIContextProvider = AuthUIContextProvider;
