"use strict";
/**
 * @packageDocumentation
 * @module RegistrationUIContext
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistrationActions = void 0;
/**
 * Named dispatch actions for account-related global state changes (i.e. load EULA, validate invite registration request, complete registration).
 */
exports.RegistrationActions = {
    loadEulaReset: function () {
        return ({
            type: 'Registration/LoadEula/Reset',
        });
    },
    loadEulaStarted: function (transitId, language) {
        return ({
            type: 'Registration/LoadEula/Started',
            payload: { transitId: transitId, language: language },
        });
    },
    loadEulaSucceeded: function (transitId) {
        return ({
            type: 'Registration/LoadEula/Succeeded',
            payload: { transitId: transitId },
        });
    },
    loadEulaFailed: function (transitId, errorMessage) {
        return ({
            type: 'Registration/LoadEula/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
    requestRegistrationCodeReset: function () {
        return ({
            type: 'Registration/RequestCode/Reset',
        });
    },
    requestRegistrationCodeStarted: function (transitId) {
        return ({
            type: 'Registration/RequestCode/Started',
            payload: { transitId: transitId },
        });
    },
    requestRegistrationCodeSucceeded: function (transitId) {
        return ({
            type: 'Registration/RequestCode/Succeeded',
            payload: { transitId: transitId },
        });
    },
    requestRegistrationCodeFailed: function (transitId, errorMessage) {
        return ({
            type: 'Registration/RequestCode/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
    validateUserRegistrationReset: function () {
        return ({
            type: 'Registration/ValidateUser/Reset',
        });
    },
    validateUserRegistrationStarted: function (transitId) {
        return ({
            type: 'Registration/ValidateUser/Started',
            payload: { transitId: transitId },
        });
    },
    validateUserRegistrationSucceeded: function (transitId) {
        return ({
            type: 'Registration/ValidateUser/Succeeded',
            payload: { transitId: transitId },
        });
    },
    validateUserRegistrationFailed: function (transitId, errorMessage) {
        return ({
            type: 'Registration/ValidateUser/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
    registerUserReset: function () {
        return ({
            type: 'Registration/RegisterUser/Reset',
        });
    },
    registerUserStarted: function (transitId) {
        return ({
            type: 'Registration/RegisterUser/Started',
            payload: { transitId: transitId },
        });
    },
    registerUserSucceeded: function (transitId, email, organizationName) {
        return ({
            type: 'Registration/RegisterUser/Succeeded',
            payload: { transitId: transitId, email: email, organizationName: organizationName },
        });
    },
    registerUserFailed: function (transitId, errorMessage) {
        return ({
            type: 'Registration/RegisterUser/Failed',
            payload: { transitId: transitId, errorMessage: errorMessage },
        });
    },
};
