"use strict";
/**
 * RegistrationStateContext and RegistrationActionContext provide access to global state and actions for registration related information (load EULA, complete registration, etc.).
 *
 * @packageDocumentation
 * @module RegistrationUIContext
 * @internal
 * @preferred
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistrationActions = exports.RegistrationActionsCreator = exports.RegistrationStateContext = exports.RegistrationActionContext = exports.useRegistrationUIActions = exports.useRegistrationUIState = void 0;
var react_1 = require("react");
var context_1 = require("./context");
Object.defineProperty(exports, "RegistrationStateContext", { enumerable: true, get: function () { return context_1.RegistrationStateContext; } });
Object.defineProperty(exports, "RegistrationActionContext", { enumerable: true, get: function () { return context_1.RegistrationActionContext; } });
__exportStar(require("./types"), exports);
__exportStar(require("./reducer"), exports);
var actions_1 = require("./actions");
Object.defineProperty(exports, "RegistrationActionsCreator", { enumerable: true, get: function () { return actions_1.RegistrationActionsCreator; } });
var dispatchActions_1 = require("./dispatchActions");
Object.defineProperty(exports, "RegistrationActions", { enumerable: true, get: function () { return dispatchActions_1.RegistrationActions; } });
/**
 * Hook for using the global account state for account-related global [[RegistrationUIState]] state changes (i.e. loading EULA, registration via invite).
 *
 * @category Hooks
 */
var useRegistrationUIState = function () {
    var context = (0, react_1.useContext)(context_1.RegistrationStateContext);
    if (context === null) {
        throw new Error('useRegistrationUIState must be used within an RegistrationUIContext');
    }
    return context;
};
exports.useRegistrationUIState = useRegistrationUIState;
/**
 * Hook for using the global [[RegistrationUIActions]] actions (i.e. loadEULA, completeRegistration, etc.) which change the global [[RegistrationUIState]].
 *
 * @category Hooks
 */
var useRegistrationUIActions = function () {
    var context = (0, react_1.useContext)(context_1.RegistrationActionContext);
    if (context === null) {
        throw new Error('useRegistrationUIActions must be used within an RegistrationUIContext');
    }
    return context;
};
exports.useRegistrationUIActions = useRegistrationUIActions;
