"use strict";
/**
 * @packageDocumentation
 * @module RegistrationUIContext
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registrationReducer = void 0;
var TransitState_1 = require("../TransitState");
/**
 * Default reducer for global [[RegistrationUIState]].
 *
 * @param prevState Previous [[RegistrationUIState]] to update.
 * @param action State change action, which should be of type [[RegistrationActions]].
 */
var registrationReducer = function (prevState, action) {
    switch (action.type) {
        case 'Registration/RegisterUser/Reset':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { registrationTransit: TransitState_1.initialTransitState, email: null, organizationName: null }) });
        case 'Registration/RegisterUser/Started':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { registrationTransit: (0, TransitState_1.transitStart)(action.payload.transitId) }) });
        case 'Registration/RegisterUser/Succeeded':
            if (prevState.inviteRegistration.registrationTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { registrationTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId), email: action.payload.email, organizationName: action.payload.organizationName }) });
        case 'Registration/RegisterUser/Failed':
            if (prevState.inviteRegistration.registrationTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { registrationTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId), email: null, organizationName: null }) });
        case 'Registration/LoadEula/Reset':
            return __assign(__assign({}, prevState), { eulaTransit: TransitState_1.initialTransitState });
        case 'Registration/LoadEula/Started':
            return __assign(__assign({}, prevState), { eulaTransit: (0, TransitState_1.transitStart)(action.payload.transitId) });
        case 'Registration/LoadEula/Succeeded':
            if (prevState.eulaTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { eulaTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId) });
        case 'Registration/LoadEula/Failed':
            if (prevState.eulaTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { eulaTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId) });
        case 'Registration/ValidateUser/Reset':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { validationTransit: TransitState_1.initialTransitState }) });
        case 'Registration/ValidateUser/Started':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { validationTransit: (0, TransitState_1.transitStart)(action.payload.transitId) }) });
        case 'Registration/ValidateUser/Succeeded':
            if (prevState.inviteRegistration.validationTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { validationTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId) }) });
        case 'Registration/ValidateUser/Failed':
            if (prevState.inviteRegistration.validationTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { validationTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId) }) });
        case 'Registration/RequestCode/Reset':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { codeRequestTransit: TransitState_1.initialTransitState }) });
        case 'Registration/RequestCode/Started':
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { codeRequestTransit: (0, TransitState_1.transitStart)(action.payload.transitId) }) });
        case 'Registration/RequestCode/Succeeded':
            if (prevState.inviteRegistration.codeRequestTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { codeRequestTransit: (0, TransitState_1.transitSuccess)(action.payload.transitId) }) });
        case 'Registration/RequestCode/Failed':
            if (prevState.inviteRegistration.codeRequestTransit.transitId !== action.payload.transitId) {
                return prevState;
            }
            return __assign(__assign({}, prevState), { inviteRegistration: __assign(__assign({}, prevState.inviteRegistration), { codeRequestTransit: (0, TransitState_1.transitFailed)(action.payload.errorMessage, action.payload.transitId) }) });
        default:
            return prevState;
    }
};
exports.registrationReducer = registrationReducer;
