"use strict";
/**
 * @packageDocumentation
 * @module SecurityContextProvider
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.reducer = void 0;
/**
 * @internal
 * @private
 *
 * Reducer for [[SecurityContextProvider]].
 *
 * @param prevState Previous [[SecurityContextState]] to update.
 * @param action State change action, which should be of type [[Action]].
 */
var reducer = function (prevState, action) {
    var _a, _b;
    switch (action.type) {
        case 'userAuthenticated':
            return {
                email: action.payload.email,
                userId: action.payload.userId,
                rememberMeDetails: {
                    email: action.payload.rememberMe ? action.payload.email : undefined,
                    rememberMe: action.payload.rememberMe,
                },
                isLoading: false,
                isSignOut: false,
                isAuthenticatedUser: true,
                isShowingChangePassword: false,
            };
        case 'userNotAuthenticated': {
            var overrideExists = ((_b = (_a = action.payload.overrideRememberMeEmail) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0) > 0;
            var rememberEmail = prevState.rememberMeDetails.email;
            var rememberMe = prevState.rememberMeDetails.rememberMe;
            if (overrideExists) {
                rememberEmail = action.payload.overrideRememberMeEmail;
                rememberMe = true;
            }
            else if (action.payload.clearRememberMe) {
                rememberEmail = undefined;
                rememberMe = false;
            }
            return {
                email: undefined,
                userId: undefined,
                rememberMeDetails: {
                    email: rememberEmail,
                    rememberMe: rememberMe,
                },
                isLoading: false,
                isSignOut: true,
                isAuthenticatedUser: false,
                isShowingChangePassword: false,
            };
        }
        case 'showChangePassword':
            return __assign(__assign({}, prevState), { isShowingChangePassword: true });
        case 'hideChangePassword':
            return __assign(__assign({}, prevState), { isShowingChangePassword: false });
        default:
            return prevState;
    }
};
exports.reducer = reducer;
