"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Clock = void 0;
var date_fns_1 = require("date-fns");
var timeTravelOffset = 0;
var frozenTime;
var internalNow = function () {
    if (frozenTime) {
        return frozenTime;
    }
    return (0, date_fns_1.subMilliseconds)(new Date(), timeTravelOffset);
};
var now = function () { return internalNow(); };
var assertInTest = function () {
    if (process.env.NODE_ENV !== 'test') {
        throw new Error('Time travel is only allowed in tests!');
    }
};
var timeTravel = function (time) {
    assertInTest();
    timeTravelOffset = (0, date_fns_1.differenceInMilliseconds)(new Date(), typeof time === 'string' ? new Date(time) : time);
    frozenTime = undefined;
};
var restoreTime = function () {
    assertInTest();
    timeTravelOffset = 0;
    frozenTime = undefined;
};
var freezeTime = function (time) {
    assertInTest();
    if (time) {
        timeTravel(time);
    }
    frozenTime = internalNow();
};
var unfreezeTime = function () {
    assertInTest();
    frozenTime = undefined;
};
exports.Clock = {
    now: now,
    Testing: {
        timeTravel: timeTravel,
        restoreTime: restoreTime,
        freezeTime: freezeTime,
        unfreezeTime: unfreezeTime,
    },
};
