import React, { ReactNode } from 'react';
import { CardProps as CardPropsType } from '@mui/material/Card';
import { SxProps, Theme } from '@mui/material/styles';
import { SpinnerProps } from '../Spinner';
import { BoxProps } from '@mui/material/Box';
import { BrandedCardContainerClasses } from './BrandedCardContainerClasses';
export type BrandedCardContainerProps = BoxProps & {
    loading?: boolean;
    backgroundImage?: string;
    cardStyles?: SxProps<Theme>;
    CardProps?: CardPropsType;
    LoaderComponent?: ReactNode;
    classes?: BrandedCardContainerClasses;
    slots?: {
        card?: React.ElementType;
        loader?: React.ElementType;
    };
    slotProps?: {
        card?: CardPropsType;
        loader?: SpinnerProps;
    };
};
/**
 * Component that renders a card centered on a blue textured background.
 *
 * @param loading if true a loading spinner will be displayed blocking the content
 *
 * @param backgroundImage will be displayed in the background instead of `defaultBackgroundImage`
 *
 * @param cardStyles will override the styles for `Card` component
 *
 * @param CardProps will be the props passed to `Card` component
 *
 * @param LoaderComponent will be displayed instead of `Spinner`
 *
 * @param classes for default style overrides
 *
 * @param slots used for each slot in `BrandedCardContainer`
 *
 * @param slotProps applied to each slot
 *
 * @category Component
 */
export declare const BrandedCardContainer: React.FC<BrandedCardContainerProps>;
