"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BrandedCardContainer = void 0;
var react_1 = __importDefault(require("react"));
var Card_1 = __importDefault(require("@mui/material/Card"));
var styles_1 = require("@mui/material/styles");
var Spinner_1 = require("../Spinner");
var background_svg_1 = __importDefault(require("../../assets/images/background.svg"));
var auth_shared_1 = require("../../auth-shared");
var Box_1 = __importDefault(require("@mui/material/Box"));
var base_1 = require("@mui/base");
var BrandedCardContainerClasses_1 = require("./BrandedCardContainerClasses");
var css_1 = require("@emotion/css");
var useUtilityClasses = function (ownerState) {
    var classes = ownerState.classes;
    var slots = {
        root: ['root'],
        card: ['card'],
    };
    return (0, base_1.unstable_composeClasses)(slots, BrandedCardContainerClasses_1.getBrandedCardContainerUtilityClass, classes);
};
/**
 * Component that renders a card centered on a blue textured background.
 *
 * @param loading if true a loading spinner will be displayed blocking the content
 *
 * @param backgroundImage will be displayed in the background instead of `defaultBackgroundImage`
 *
 * @param cardStyles will override the styles for `Card` component
 *
 * @param CardProps will be the props passed to `Card` component
 *
 * @param LoaderComponent will be displayed instead of `Spinner`
 *
 * @param classes for default style overrides
 *
 * @param slots used for each slot in `BrandedCardContainer`
 *
 * @param slotProps applied to each slot
 *
 * @category Component
 */
var BrandedCardContainer = function (props) {
    var _a;
    var children = props.children, loading = props.loading, backgroundImage = props.backgroundImage, cardStyles = props.cardStyles, CardProps = props.CardProps, _b = props.slots, slots = _b === void 0 ? {} : _b, _c = props.slotProps, slotProps = _c === void 0 ? {} : _c, _d = props.LoaderComponent, LoaderComponent = _d === void 0 ? react_1.default.createElement(Spinner_1.Spinner, __assign({ visible: loading, component: slots.loader }, slotProps.loader)) : _d, _e = props.classes, classes = _e === void 0 ? {} : _e, userClassName = props.className, otherProps = __rest(props, ["children", "loading", "backgroundImage", "cardStyles", "CardProps", "slots", "slotProps", "LoaderComponent", "classes", "className"]);
    var background = (0, auth_shared_1.useInjectedUIContext)().background;
    var theme = (0, styles_1.useTheme)();
    var defaultClasses = useUtilityClasses(props);
    return (react_1.default.createElement(Box_1.default, __assign({ sx: {
            height: '100vh',
            width: '100%',
            backgroundColor: theme.palette.mode === 'light' ? 'primary.main' : 'primary.dark',
            backgroundImage: backgroundImage ? "url(".concat(backgroundImage, ")") : "url(".concat(background_svg_1.default, ")"),
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'center',
        }, style: background || {}, className: (0, css_1.cx)(defaultClasses.root, classes.root, userClassName) }, otherProps),
        react_1.default.createElement(Card_1.default, __assign({ sx: __assign((_a = { width: '100%', height: '100%', maxWidth: '450px', maxHeight: '730px', overflow: 'auto', display: 'flex', flexDirection: 'column', position: 'relative' }, _a[theme.breakpoints.down('sm')] = {
                maxWidth: 'none',
                maxHeight: 'none',
                borderRadius: 0,
            }, _a), cardStyles), className: (0, css_1.cx)(defaultClasses.card, classes.card), component: slots.card }, CardProps, slotProps.card),
            LoaderComponent,
            children)));
};
exports.BrandedCardContainer = BrandedCardContainer;
