import React, { MutableRefObject } from 'react';
export type ChangePasswordFormProps = {
    onPasswordChange: (passwords: {
        password: string;
        confirm: string;
    }) => void;
    initialPassword?: string;
    initialConfirm?: string;
    passwordLabel?: string;
    confirmLabel?: string;
    description?: string;
    passwordRef?: MutableRefObject<any>;
    confirmRef?: MutableRefObject<any>;
    onSubmit?: () => void;
};
/**
 * Component that renders a change password form with a new password and confirm password inputs.
 * It includes callbacks so you can respond to changes in the inputs.
 *
 * @param onPasswordChange Fired when the new password or confirm new password fields value changes
 * @param initialPassword Value to initialize the password field
 * @param initialConfirm Value to initialize the confirm field
 * @param passwordLabel Optional label for the new password field (default = 'Password')
 * @param confirmLabel Optional label for the confirm password field (default = 'Confirm')
 * @param description Optional text to replace the instructional text above the password fields.
 * @param passwordRef Optional ref to forward to the password input.
 * @param confirmRef Optional ref to forward to the confirm password input.
 * @param onSubmit Optional callback function to call when the mini form is submitted.
 *
 * @category Component
 */
export declare const ChangePasswordForm: React.FC<React.PropsWithChildren<React.PropsWithChildren<ChangePasswordFormProps>>>;
