/**
 * @packageDocumentation
 * @module Hooks
 * @internal
 */
import { TFunction } from 'i18next';
export type Fn<T, U> = (t: T) => U;
export type UnionKeys<T> = T[keyof T];
export type PromiseType<T> = T extends PromiseLike<infer U> ? U : T;
export type AsStrings<T> = {
    [P in keyof T]: string;
};
export type ValueOf<T> = T[keyof T];
export type ActionType<TActions extends {
    [k: string]: any;
}> = ReturnType<ValueOf<TActions>>;
export type ArgumentsType<T extends (...args: any[]) => any> = T extends (...args: infer A) => any ? A : never;
export type FirstArgument<T> = T extends (arg1: infer U, ...args: any[]) => any ? U : any;
export type SecondArgument<T> = T extends (arg1: any, arg2: infer U, ...args: any[]) => any ? U : any;
export type ThirdArgument<T> = T extends (arg1: any, arg2: any, arg3: infer U, ...args: any[]) => any ? U : any;
type TFunctionWithNoDataDefault = (key: FirstArgument<TFunction>, options?: ThirdArgument<TFunction>) => string;
export declare const useLanguageLocale: () => {
    t: TFunctionWithNoDataDefault;
    formatDateTime: (dateTime: string | undefined | null) => string;
    formatMonthLong: (dateTime: string | undefined | null) => string;
    formatDate: (dateTime: string | undefined | null) => string;
    formatDateShort: (dateTime: string | undefined | null) => string;
    formatTime: (dateTime: string | undefined | null) => string;
    formatTimeShort: (dateTime: string | undefined | null) => string;
    timeSince: (dateTime: string | undefined | null) => string;
};
export type LanguageLocale = ReturnType<typeof useLanguageLocale>;
export {};
