import React, { ReactNode } from 'react';
import { CardActionsProps as CardActionsPropsType } from '@mui/material/CardActions';
import { CardContentProps as CardContentPropsType } from '@mui/material/CardContent';
import { CardHeaderProps as CardHeaderPropsType } from '@mui/material/CardHeader';
import { TypographyProps } from '@mui/material/Typography';
import { ContactSupportSubscreenClasses } from './ContactSupportSubscreenClasses';
export type ContactSupportSubscreenHiddenElements = {
    title?: boolean;
    contactSupportSubscreenContent?: boolean;
    contactSupportSubscreenIcon?: boolean;
    contactSupportSubscreenQuestion?: boolean;
    contactSupportSubscreenMessage?: boolean;
    contactSupportSubscreenEmergency?: boolean;
    contactSupportSubscreenTechnicalAssistance?: boolean;
    actions?: boolean;
};
export type ContactSupportSubscreenProps = {
    title?: string;
    TitleProps?: TypographyProps;
    Actions?: JSX.Element | JSX.Element[];
    divider?: boolean;
    ContactSupportSubscreenContent?: JSX.Element;
    CardHeaderProps?: CardHeaderPropsType;
    CardContentProps?: CardContentPropsType;
    CardActionsProps?: CardActionsPropsType;
    phoneNumber?: string;
    emailId?: string;
    contactSupportSubscreenQuestion?: string;
    contactSupportSubscreenMessage?: string;
    contactSupportSubscreenEmergency?: string;
    contactSupportSubscreenTechnicalAssistance?: string;
    ContactSupportSubscreenIcon?: ReactNode;
    hiddenElements?: ContactSupportSubscreenHiddenElements;
    classes?: ContactSupportSubscreenClasses;
    slots?: {
        cardHeader?: React.ElementType;
        cardContent?: React.ElementType;
    };
    slotProps?: {
        cardHeader?: CardHeaderPropsType;
        cardContent?: CardContentPropsType;
    };
};
/**
 * Component renders a screen with contact information for support with the application.
 * Contact information is pulled from the context passed into the workflow.
 *
 * @param title to display in the header
 *
 * @param TitleProps Props to pass to title
 *
 * @param Actions to display inside `CardActions`
 *
 * @param divider which appears above `Actions`
 *
 * @param ContactSupportSubscreenContent to display the contact support content
 *
 * @param CardHeaderProps Props to pass to `CardHeader`
 *
 * @param CardContentProps Props to pass to `CardContent`
 *
 * @param CardActionsProps Props to pass to `CardActions`
 *
 * @param phoneNumber to override contact phone number
 *
 * @param emailId to override contact email id
 *
 * @param contactSupportSubscreenQuestion to override contact support question
 *
 * @param contactSupportSubscreenMessage to override contact support message
 *
 * @param contactSupportSubscreenEmergency to override contact support emergency support
 *
 * @param contactSupportSubscreenTechnicalAssistance to override contact support technical assistance
 *
 * @param ContactSupportSubscreenIcon to render the icon
 *
 * @param hiddenElements to hide various elements of the component
 *
 * @param classes for default style overrides
 *
 * @param slots used for each slot in `ContactSupportSubscreen`
 *
 * @param slotProps applied to each slot
 *
 * @category Component
 */
export declare const ContactSupportSubscreen: React.FC<ContactSupportSubscreenProps>;
