"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContactSupportSubscreen = void 0;
var react_1 = __importDefault(require("react"));
var react_router_dom_1 = require("react-router-dom");
var Button_1 = __importDefault(require("@mui/material/Button"));
var Box_1 = __importDefault(require("@mui/material/Box"));
var Divider_1 = __importDefault(require("@mui/material/Divider"));
var CardActions_1 = __importDefault(require("@mui/material/CardActions"));
var CardContent_1 = __importDefault(require("@mui/material/CardContent"));
var CardHeader_1 = __importDefault(require("@mui/material/CardHeader"));
var Typography_1 = __importDefault(require("@mui/material/Typography"));
var styles_1 = require("@mui/material/styles");
var base_1 = require("@mui/base");
var css_1 = require("@emotion/css");
var ChatBubbleOutline_1 = __importDefault(require("@mui/icons-material/ChatBubbleOutline"));
var styles_2 = require("../../../styles");
var ContactSupportSubscreenClasses_1 = require("./ContactSupportSubscreenClasses");
var auth_shared_1 = require("../../../auth-shared");
var LinkStyles = {
    fontWeight: 600,
    color: 'primary.main',
    textTransform: 'none',
    textDecoration: 'none',
    '&:visited': {
        color: 'primary.main',
    },
};
var useUtilityClasses = function (ownerState) {
    var classes = ownerState.classes;
    var slots = {
        cardHeader: ['cardHeader'],
        cardContent: ['cardContent'],
        cardActions: ['cardActions'],
    };
    return (0, base_1.unstable_composeClasses)(slots, ContactSupportSubscreenClasses_1.getContactSupportSubscreenUtilityClass, classes);
};
/**
 * Component renders a screen with contact information for support with the application.
 * Contact information is pulled from the context passed into the workflow.
 *
 * @param title to display in the header
 *
 * @param TitleProps Props to pass to title
 *
 * @param Actions to display inside `CardActions`
 *
 * @param divider which appears above `Actions`
 *
 * @param ContactSupportSubscreenContent to display the contact support content
 *
 * @param CardHeaderProps Props to pass to `CardHeader`
 *
 * @param CardContentProps Props to pass to `CardContent`
 *
 * @param CardActionsProps Props to pass to `CardActions`
 *
 * @param phoneNumber to override contact phone number
 *
 * @param emailId to override contact email id
 *
 * @param contactSupportSubscreenQuestion to override contact support question
 *
 * @param contactSupportSubscreenMessage to override contact support message
 *
 * @param contactSupportSubscreenEmergency to override contact support emergency support
 *
 * @param contactSupportSubscreenTechnicalAssistance to override contact support technical assistance
 *
 * @param ContactSupportSubscreenIcon to render the icon
 *
 * @param hiddenElements to hide various elements of the component
 *
 * @param classes for default style overrides
 *
 * @param slots used for each slot in `ContactSupportSubscreen`
 *
 * @param slotProps applied to each slot
 *
 * @category Component
 */
var ContactSupportSubscreen = function (props) {
    var t = (0, auth_shared_1.useLanguageLocale)().t;
    var navigate = (0, react_router_dom_1.useNavigate)();
    var theme = (0, styles_1.useTheme)();
    var _a = (0, auth_shared_1.useInjectedUIContext)(), contactPhone = _a.contactPhone, contactEmail = _a.contactEmail;
    var defaultClasses = useUtilityClasses(props);
    var _b = props.title, title = _b === void 0 ? t('blui:USER_MENU.CONTACT_US') : _b, TitleProps = props.TitleProps, _c = props.Actions, Actions = _c === void 0 ? (react_1.default.createElement(Button_1.default, { variant: "contained", color: "primary", disableElevation: true, sx: (0, styles_2.DialogButtonStyles)(true), onClick: function () { return navigate(-1); } }, t('blui:ACTIONS.OKAY'))) : _c, _d = props.divider, divider = _d === void 0 ? true : _d, ContactSupportSubscreenContent = props.ContactSupportSubscreenContent, CardHeaderProps = props.CardHeaderProps, CardContentProps = props.CardContentProps, CardActionsProps = props.CardActionsProps, _e = props.phoneNumber, phoneNumber = _e === void 0 ? contactPhone : _e, _f = props.emailId, emailId = _f === void 0 ? contactEmail : _f, _g = props.contactSupportSubscreenQuestion, contactSupportSubscreenQuestion = _g === void 0 ? t('blui:CONTACT_SUPPORT.GENERAL_QUESTIONS') : _g, _h = props.contactSupportSubscreenMessage, contactSupportSubscreenMessage = _h === void 0 ? t('blui:CONTACT_SUPPORT.SUPPORT_MESSAGE') : _h, _j = props.contactSupportSubscreenEmergency, contactSupportSubscreenEmergency = _j === void 0 ? t('blui:CONTACT_SUPPORT.EMERGENCY_SUPPORT') : _j, _k = props.contactSupportSubscreenTechnicalAssistance, contactSupportSubscreenTechnicalAssistance = _k === void 0 ? t('blui:CONTACT_SUPPORT.TECHNICAL_ASSISTANCE') : _k, _l = props.ContactSupportSubscreenIcon, ContactSupportSubscreenIcon = _l === void 0 ? react_1.default.createElement(ChatBubbleOutline_1.default, { fontSize: 'inherit', color: 'primary' }) : _l, _m = props.hiddenElements, hiddenElements = _m === void 0 ? {} : _m, _o = props.classes, classes = _o === void 0 ? {} : _o, _p = props.slots, slots = _p === void 0 ? {} : _p, _q = props.slotProps, slotProps = _q === void 0 ? {} : _q;
    return (react_1.default.createElement(react_1.default.Fragment, null,
        !hiddenElements.title && (react_1.default.createElement(CardHeader_1.default, __assign({ title: react_1.default.createElement(Typography_1.default, __assign({ variant: 'h6' }, TitleProps), title), sx: (0, styles_2.DialogTitleStyles)(theme), className: (0, css_1.cx)(defaultClasses.cardHeader, classes.cardHeader), component: slots.cardHeader }, CardHeaderProps, slotProps.cardHeader))),
        !hiddenElements.contactSupportSubscreenContent && (react_1.default.createElement(CardContent_1.default, __assign({ sx: (0, styles_2.DialogContentStyles)(theme), className: (0, css_1.cx)(defaultClasses.cardContent, classes.cardContent), component: slots.cardContent }, CardContentProps, slotProps.cardContent), ContactSupportSubscreenContent ? (ContactSupportSubscreenContent) : (react_1.default.createElement(react_1.default.Fragment, null,
            !hiddenElements.contactSupportSubscreenIcon && (react_1.default.createElement(Box_1.default, { sx: { fontSize: 70, mb: 4, textAlign: 'center' } }, ContactSupportSubscreenIcon)),
            !hiddenElements.contactSupportSubscreenQuestion && (react_1.default.createElement(Typography_1.default, { variant: 'body1', sx: { mb: 1 } }, contactSupportSubscreenQuestion)),
            !hiddenElements.contactSupportSubscreenMessage && (react_1.default.createElement(Typography_1.default, null,
                contactSupportSubscreenMessage,
                react_1.default.createElement(Box_1.default, { component: "a", href: "mailto:".concat(emailId), sx: LinkStyles }, emailId),
                ".")),
            !hiddenElements.contactSupportSubscreenEmergency && (react_1.default.createElement(Typography_1.default, { variant: 'body1', sx: { mt: 4, mb: 1 } }, contactSupportSubscreenEmergency)),
            !hiddenElements.contactSupportSubscreenTechnicalAssistance && (react_1.default.createElement(Typography_1.default, null,
                contactSupportSubscreenTechnicalAssistance,
                react_1.default.createElement(Box_1.default, { component: "a", href: "tel:".concat(phoneNumber), sx: LinkStyles }, phoneNumber),
                ".")))))),
        divider && react_1.default.createElement(Divider_1.default, null),
        !hiddenElements.actions && (react_1.default.createElement(CardActions_1.default, __assign({ sx: (0, styles_2.DialogActionsStyles)(theme), className: (0, css_1.cx)(defaultClasses.cardActions, classes.cardActions) }, CardActionsProps), Actions))));
};
exports.ContactSupportSubscreen = ContactSupportSubscreen;
