import React from 'react';
import { FormControlLabelProps } from '@mui/material/FormControlLabel';
import { BoxProps } from '@mui/material/Box';
import { ViewEulaSubscreenClasses } from './ViewEulaSubscreenClasses';
export type ViewEulaSubscreenProps = {
    eulaAccepted: boolean;
    onEulaCheckboxChanged: (accepted: boolean) => void;
    loadEulaAction: (language: string) => Promise<string>;
    htmlEula?: boolean;
    eulaError?: string;
    agreeTerms?: string;
    classes?: ViewEulaSubscreenClasses;
    slots?: {
        loader?: React.ElementType;
        eulaContent?: React.ElementType;
        checkboxLabel?: React.ElementType;
    };
    slotProps?: {
        loader?: any;
        eulaContent?: BoxProps;
        checkboxLabel?: FormControlLabelProps;
    };
};
/**
 * Component that renders a screen displaying the EULA and requests acceptance via a checkbox.
 *
 * @param eulaAccepted true if the checkbox should be checked
 *
 * @param eulaContent the content to render for the EULA. Can be a plain string or HTML
 *
 * @param onEulaCheckboxChanged function to call when the state of the checkbox is changed
 *
 * @param loadEula function to call to retrieve the eulaContent
 *
 * @param htmlEula true if the EULA should be rendered as HTML
 *
 * @param eulaError error message if the EULA fails to load
 *
 * @param agreeTerms to override terms and conditions text
 *
 * @param slots used for each slot in `ContactSupport`
 *
 * @param slotProps applied to each slot
 *
 * @category Component
 */
export declare const ViewEulaSubscreen: React.FC<ViewEulaSubscreenProps>;
